version 8.2
clear
set logtype text
set more off
set matsize 200

capture mkdir "brazrloc/estmat/v4/reg"
capture mkdir "brazrloc/estmat/v4/reg/natl"

capture log close
log using "brazrloc/logs/separations-accessions-nosec13-natl.log", replace

local maxiter $maxiter

capture program drop ivreplc
program define ivreplc
  foreach reg in $regdef {
    replace imp_`reg' = imp_`reg' * ini_lnempl
    }
end

// SUBSIBGE REGRESSIONS

local nosec13lst   "subs_balcadv firm_indexp"
local cntrlfrm "subs_secrealx subs_fdiflw subs_herfsale plant_lnempl plant_indprim plant_indhigh plant_indwhittot"
local endog    "subs_tarfoutp subs_tarfintm subs_reffpen"
local baseiv   "subs_dollar subs_ppieu subs_ppinam"
local expiv    "imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU"
local focallst "subs_balcadv subs_balcadv_tarf firm_indexp firm_indexp_tarf"
local addlst   "subs_balcadv_indexp subs_balcadv_indexp_tarf"


* separations natl

local cntrlwrk "tenuryr potexper indprof indtech indwhit indsklb indfemal"

use if ~indexcl using "brazrloc/data/separations-natl-subsibge.dta", clear
drop if indsubs_13==1

* obtain alternative instrumental variables
gen byte subs_ibge = .
forvalues i = 1/26 {
  qui replace subs_ibge = `i' if indsubs_`i'==1
  }
drop imp_*
sort subs_ibge year
merge subs_ibge year using "brazrloc/auxil/wtf-subsibge-data.dta", nokeep
qui count if _m~=3
if `r(N)'>0  STOP
drop _m subs_ibge
egen ini_lnempl = mean(plant_lnempl) if year<=1990, by(cnpj_radic)
egen _spread = min(ini_lnempl), by(cnpj_radic)
replace ini_lnempl = _spread if ini_lnempl==.
drop _spread
label var ini_lnempl "Firm Log Employment 1986-90"

* annual trend
gen byte trend = year - 1986
label var trend "Annual Trend"

clogit inddspl `nosec13lst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_nosec13, vars(subs_balcadv subs_balcadv_tarf firm_indexp firm_indexp_tarf subs_balcadv_indexp subs_balcadv_indexp_tarf subs_tarfoutp subs_tarfintm subs_reffpen prd_subs_tarfoutp res_subs_tarfoutp prd_subs_tarfintm res_subs_tarfintm prd_subs_reffpen res_subs_reffpen prd_indexp res_indexp subs_secrealx subs_fdiflw subs_herfsale subs_indprown_pis occ_indoutsrc plant_lnempl plant_indprim plant_indhigh plant_indwhittot firm_lnlp tenuryr tenr2 potexper potxper2 indprof indtech indwhit indsklb indunsklb indfemal indprim indhigh indscoll indgrad trend indyr_1 indyr_2 indyr_3 indyr_4 indyr_5 indyr_6 indyr_7 indyr_8 indyr_9 indyr_10 indyr_11 indyr_12 indyr_13 indsubs_1 indsubs_2 indsubs_3 indsubs_4 indsubs_5 indsubs_6 indsubs_7 indsubs_8 indsubs_9 indsubs_10 indsubs_11 indsubs_12 indsubs_13 indsubs_14 indsubs_15 indsubs_16 indsubs_17 indsubs_18 indsubs_19 indsubs_20 indsubs_21 indsubs_22 indsubs_23 indsubs_24 indsubs_25 indsubs_26 subs_dollar subs_ppieu subs_ppinam imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU) e(N ll chi2 p df_m r2 r2_p rc ic) name(clogit_paper)
est2vec subsdspl_nosec13, r(F p df df_r) name(clogit_paper)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In clogit sample"
tab year if indsmpl

clogit inddspl `nosec13lst' `endog' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_nosec13, addto(subsdspl_nosec13) name(clogit_nosec13)
est2vec subsdspl_nosec13, raddto(subsdspl_nosec13) name(clogit_nosec13)

clogit inddspl `focallst' `endog' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_nosec13, addto(subsdspl_nosec13) name(clogit_focal)
est2vec subsdspl_nosec13, raddto(subsdspl_nosec13) name(clogit_focal)

clogit inddspl `focallst' `addlst' `endog' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_nosec13, addto(subsdspl_nosec13) name(clogit_all)
est2vec subsdspl_nosec13, raddto(subsdspl_nosec13) name(clogit_all)

clogit inddspl `nosec13lst' `endog' `cntrlfrm' `cntrlwrk' indsubs* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_nosec13, addto(subsdspl_nosec13) name(clogit_noyreff)
est2vec subsdspl_nosec13, raddto(subsdspl_nosec13) name(clogit_noyreff)

clogit inddspl `nosec13lst' `endog' `cntrlfrm' `cntrlwrk' indsubs* trend if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_nosec13, addto(subsdspl_nosec13) name(clogit_trend)
est2vec subsdspl_nosec13, raddto(subsdspl_nosec13) name(clogit_trend)

clogit inddspl subs_balcadv `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_nosec13, addto(subsdspl_nosec13) name(clogit_balcadv)
est2vec subsdspl_nosec13, raddto(subsdspl_nosec13) name(clogit_balcadv)

clogit inddspl firm_indexp `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_nosec13, addto(subsdspl_nosec13) name(clogit_indexp)
est2vec subsdspl_nosec13, raddto(subsdspl_nosec13) name(clogit_indexp)

clogit inddspl subs_tarfoutp subs_tarfintm `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_nosec13, addto(subsdspl_nosec13) name(clogit_tarf)
est2vec subsdspl_nosec13, raddto(subsdspl_nosec13) name(clogit_tarf)

clogit inddspl subs_reffpen `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_nosec13, addto(subsdspl_nosec13) name(clogit_reffpen)
est2vec subsdspl_nosec13, raddto(subsdspl_nosec13) name(clogit_reffpen)

xtreg inddspl subs_balcadv firm_indexp `endog' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid)
est2vec subsdspl_nosec13, addto(subsdspl_nosec13) name(xt)
est2vec subsdspl_nosec13, raddto(subsdspl_nosec13) name(xt)

xtreg inddspl subs_balcadv firm_indexp `endog' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indsmpl, fe i(wid)
est2vec subsdspl_nosec13, addto(subsdspl_nosec13) name(xt_ifclogit)
est2vec subsdspl_nosec13, raddto(subsdspl_nosec13) name(xt_ifclogit)

xtivreg inddspl subs_balcadv `cntrlfrm' `cntrlwrk' indsubs* indyr* (firm_indexp `endog' = `baseiv' `expiv') if year>=1990, fe i(wid)
est2vec subsdspl_nosec13, addto(subsdspl_nosec13) name(xtiv)
est2vec subsdspl_nosec13, raddto(subsdspl_nosec13) name(xtiv)

xtivreg inddspl subs_balcadv `cntrlfrm' `cntrlwrk' indsubs* indyr* (firm_indexp `endog' = `baseiv' `expiv') if indsmpl, fe i(wid)
est2vec subsdspl_nosec13, addto(subsdspl_nosec13) name(xtiv_ifclogit)
est2vec subsdspl_nosec13, raddto(subsdspl_nosec13) name(xtiv_ifclogit)

xtivreg inddspl subs_balcadv subs_tarfoutp subs_tarfintm `cntrlfrm' `cntrlwrk' indsubs* indyr* (firm_indexp subs_reffpen = `baseiv' `expiv') if indsmpl, fe i(wid)
est2vec subsdspl_nosec13, addto(subsdspl_nosec13) name(xtiv_exogtarf)
est2vec subsdspl_nosec13, raddto(subsdspl_nosec13) name(xtiv_exogtarf)

ivreplc
xtivreg inddspl subs_balcadv subs_tarfoutp subs_tarfintm `cntrlfrm' `cntrlwrk' indsubs* indyr* (firm_indexp subs_reffpen = `baseiv' `expiv') if indsmpl, fe i(wid)
est2vec subsdspl_nosec13, addto(subsdspl_nosec13) name(xtiv_iniempl)
est2vec subsdspl_nosec13, raddto(subsdspl_nosec13) name(xtiv_iniempl)

logit inddspl `nosec13lst' `endog' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indsmpl, robust iterate(`maxiter')
est2vec subsdspl_nosec13, addto(subsdspl_nosec13) name(logit_ifclogit)
est2vec subsdspl_nosec13, raddto(subsdspl_nosec13) name(logit_ifclogit)

logit inddspl `nosec13lst' `endog' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, robust iterate(`maxiter')
est2vec subsdspl_nosec13, addto(subsdspl_nosec13) name(logit)
est2vec subsdspl_nosec13, raddto(subsdspl_nosec13) name(logit)

clogit inddspl `nosec13lst' `endog' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indprim & year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_nosec13, addto(subsdspl_nosec13) name(clogit_indprim)
est2vec subsdspl_nosec13, raddto(subsdspl_nosec13) name(clogit_indprim)

clogit inddspl `nosec13lst' `endog' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indhigh & year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_nosec13, addto(subsdspl_nosec13) name(clogit_indhigh)
est2vec subsdspl_nosec13, raddto(subsdspl_nosec13) name(clogit_indhigh)

clogit inddspl `nosec13lst' `endog' `cntrlfrm' `cntrlwrk' indsubs* indyr* if (indscoll | indgrad) & year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_nosec13, addto(subsdspl_nosec13) name(clogit_indcoll)
est2vec subsdspl_nosec13, raddto(subsdspl_nosec13) name(clogit_indcoll)

clogit inddspl `nosec13lst' `endog' `cntrlfrm' `cntrlwrk' indsubs* indyr* if potexper < 10 & year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_nosec13, addto(subsdspl_nosec13) name(clogit_indyoung)
est2vec subsdspl_nosec13, raddto(subsdspl_nosec13) name(clogit_indyoung)

clogit inddspl `nosec13lst' `endog' `cntrlfrm' `cntrlwrk' indsubs* subs_indprown_pis indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_nosec13, addto(subsdspl_nosec13) name(clogit_indprown)
est2vec subsdspl_nosec13, raddto(subsdspl_nosec13) name(clogit_indprown)

clogit inddspl `nosec13lst' `endog' `cntrlfrm' `cntrlwrk' indsubs* occ_indoutsrc indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_nosec13, addto(subsdspl_nosec13) name(clogit_indoutsrc)
est2vec subsdspl_nosec13, raddto(subsdspl_nosec13) name(clogit_indoutsrc)

clogit inddspl `nosec13lst' `endog' `cntrlfrm' `cntrlwrk' indsubs* firm_lnlp indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_nosec13, addto(subsdspl_nosec13) name(clogit_lnlp)
est2vec subsdspl_nosec13, raddto(subsdspl_nosec13) name(clogit_lnlp)
gen byte indpia = e(sample)
label var indpia "Indic.: In PIA (lnlp) sample"

clogit inddspl `nosec13lst' `endog' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indpia, group(wid) robust iterate(`maxiter')
est2vec subsdspl_nosec13, addto(subsdspl_nosec13) name(clogit_ifpia)
est2vec subsdspl_nosec13, raddto(subsdspl_nosec13) name(clogit_ifpia)

xtreg firm_indexp `baseiv' `expiv' subs_balcadv `cntrlfrm' `cntrlwrk' indsubs* indyr* if indsmpl, fe i(wid)
est2vec subsdspl_nosec13, addto(subsdspl_nosec13) name(first_indexp)
test `baseiv' `expiv'
est2vec subsdspl_nosec13, raddto(subsdspl_nosec13) name(first_indexp)

xtreg subs_tarfoutp `baseiv' `expiv' subs_balcadv `cntrlfrm' `cntrlwrk' indsubs* indyr* if indsmpl, fe i(wid)
est2vec subsdspl_nosec13, addto(subsdspl_nosec13) name(first_tarfoutp)
test `baseiv' `expiv'
est2vec subsdspl_nosec13, raddto(subsdspl_nosec13) name(first_tarfoutp)

xtreg subs_tarfintm `baseiv' `expiv' subs_balcadv `cntrlfrm' `cntrlwrk' indsubs* indyr* if indsmpl, fe i(wid)
est2vec subsdspl_nosec13, addto(subsdspl_nosec13) name(first_tarfintm)
test `baseiv' `expiv'
est2vec subsdspl_nosec13, raddto(subsdspl_nosec13) name(first_tarfintm)

xtreg subs_reffpen `baseiv' `expiv' subs_balcadv `cntrlfrm' `cntrlwrk' indsubs* indyr* if indsmpl, fe i(wid)
est2vec subsdspl_nosec13, addto(subsdspl_nosec13) name(first_reffpen)
test `baseiv' `expiv'
est2vec subsdspl_nosec13, raddto(subsdspl_nosec13) name(first_reffpen)


* accessions natl

local cntrlwrk "indprof indtech indwhit indsklb indfemal"

use if ~indexcl using "brazrloc/data/accessions-natl-subsibge.dta", clear
drop if indsubs_13==1

* obtain alternative instrumental variables
gen byte subs_ibge = .
forvalues i = 1/26 {
  qui replace subs_ibge = `i' if indsubs_`i'==1
  }
drop imp_*
sort subs_ibge year
merge subs_ibge year using "brazrloc/auxil/wtf-subsibge-data.dta", nokeep
qui count if _m~=3
if `r(N)'>0  STOP
drop _m subs_ibge
egen ini_lnempl = mean(plant_lnempl) if year<=1990, by(cnpj_radic)
egen _spread = min(ini_lnempl), by(cnpj_radic)
replace ini_lnempl = _spread if ini_lnempl==.
drop _spread
label var ini_lnempl "Firm Log Employment 1986-90"

* annual trend
gen byte trend = year - 1986
label var trend "Annual Trend"

clogit indhire `nosec13lst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_nosec13, vars(subs_balcadv subs_balcadv_tarf firm_indexp firm_indexp_tarf subs_balcadv_indexp subs_balcadv_indexp_tarf subs_tarfoutp subs_tarfintm subs_reffpen prd_subs_tarfoutp res_subs_tarfoutp prd_subs_tarfintm res_subs_tarfintm prd_subs_reffpen res_subs_reffpen prd_indexp res_indexp subs_secrealx subs_fdiflw subs_herfsale subs_indprown_pis occ_indoutsrc plant_lnempl plant_indprim plant_indhigh plant_indwhittot firm_lnlp tenuryr tenr2 potexper potxper2 indprof indtech indwhit indsklb indunsklb indfemal indprim indhigh indscoll indgrad trend indyr_1 indyr_2 indyr_3 indyr_4 indyr_5 indyr_6 indyr_7 indyr_8 indyr_9 indyr_10 indyr_11 indyr_12 indyr_13 indsubs_1 indsubs_2 indsubs_3 indsubs_4 indsubs_5 indsubs_6 indsubs_7 indsubs_8 indsubs_9 indsubs_10 indsubs_11 indsubs_12 indsubs_13 indsubs_14 indsubs_15 indsubs_16 indsubs_17 indsubs_18 indsubs_19 indsubs_20 indsubs_21 indsubs_22 indsubs_23 indsubs_24 indsubs_25 indsubs_26 subs_dollar subs_ppieu subs_ppinam imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU) e(N ll chi2 p df_m r2 r2_p rc ic) name(clogit_paper)
est2vec subshire_nosec13, r(F p df df_r) name(clogit_paper)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In clogit sample"
tab year if indsmpl

clogit indhire `nosec13lst' `endog' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_nosec13, addto(subshire_nosec13) name(clogit_nosec13)
est2vec subshire_nosec13, raddto(subshire_nosec13) name(clogit_nosec13)

clogit indhire `focallst' `endog' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_nosec13, addto(subshire_nosec13) name(clogit_focal)
est2vec subshire_nosec13, raddto(subshire_nosec13) name(clogit_focal)

clogit indhire `focallst' `addlst' `endog' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_nosec13, addto(subshire_nosec13) name(clogit_all)
est2vec subshire_nosec13, raddto(subshire_nosec13) name(clogit_all)

clogit indhire `nosec13lst' `endog' `cntrlfrm' `cntrlwrk' indsubs* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_nosec13, addto(subshire_nosec13) name(clogit_noyreff)
est2vec subshire_nosec13, raddto(subshire_nosec13) name(clogit_noyreff)

clogit indhire `nosec13lst' `endog' `cntrlfrm' `cntrlwrk' indsubs* trend if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_nosec13, addto(subshire_nosec13) name(clogit_trend)
est2vec subshire_nosec13, raddto(subshire_nosec13) name(clogit_trend)

clogit indhire subs_balcadv `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_nosec13, addto(subshire_nosec13) name(clogit_balcadv)
est2vec subshire_nosec13, raddto(subshire_nosec13) name(clogit_balcadv)

clogit indhire firm_indexp `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_nosec13, addto(subshire_nosec13) name(clogit_indexp)
est2vec subshire_nosec13, raddto(subshire_nosec13) name(clogit_indexp)

clogit indhire subs_tarfoutp subs_tarfintm `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_nosec13, addto(subshire_nosec13) name(clogit_tarf)
est2vec subshire_nosec13, raddto(subshire_nosec13) name(clogit_tarf)

clogit indhire subs_reffpen `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_nosec13, addto(subshire_nosec13) name(clogit_reffpen)
est2vec subshire_nosec13, raddto(subshire_nosec13) name(clogit_reffpen)

xtreg indhire subs_balcadv firm_indexp `endog' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid)
est2vec subshire_nosec13, addto(subshire_nosec13) name(xt)
est2vec subshire_nosec13, raddto(subshire_nosec13) name(xt)

xtreg indhire subs_balcadv firm_indexp `endog' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indsmpl, fe i(wid)
est2vec subshire_nosec13, addto(subshire_nosec13) name(xt_ifclogit)
est2vec subshire_nosec13, raddto(subshire_nosec13) name(xt_ifclogit)

xtivreg indhire subs_balcadv `cntrlfrm' `cntrlwrk' indsubs* indyr* (firm_indexp `endog' = `baseiv' `expiv') if year>=1990, fe i(wid)
est2vec subshire_nosec13, addto(subshire_nosec13) name(xtiv)
est2vec subshire_nosec13, raddto(subshire_nosec13) name(xtiv)

xtivreg indhire subs_balcadv `cntrlfrm' `cntrlwrk' indsubs* indyr* (firm_indexp `endog' = `baseiv' `expiv') if indsmpl, fe i(wid)
est2vec subshire_nosec13, addto(subshire_nosec13) name(xtiv_ifclogit)
est2vec subshire_nosec13, raddto(subshire_nosec13) name(xtiv_ifclogit)

xtivreg indhire subs_balcadv subs_tarfoutp subs_tarfintm `cntrlfrm' `cntrlwrk' indsubs* indyr* (firm_indexp subs_reffpen = `baseiv' `expiv') if indsmpl, fe i(wid)
est2vec subshire_nosec13, addto(subshire_nosec13) name(xtiv_exogtarf)
est2vec subshire_nosec13, raddto(subshire_nosec13) name(xtiv_exogtarf)

ivreplc
xtivreg indhire subs_balcadv subs_tarfoutp subs_tarfintm `cntrlfrm' `cntrlwrk' indsubs* indyr* (firm_indexp subs_reffpen = `baseiv' `expiv') if indsmpl, fe i(wid)
est2vec subshire_nosec13, addto(subshire_nosec13) name(xtiv_iniempl)
est2vec subshire_nosec13, raddto(subshire_nosec13) name(xtiv_iniempl)

logit indhire `nosec13lst' `endog' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indsmpl, robust iterate(`maxiter')
est2vec subshire_nosec13, addto(subshire_nosec13) name(logit_ifclogit)
est2vec subshire_nosec13, raddto(subshire_nosec13) name(logit_ifclogit)

logit indhire `nosec13lst' `endog' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, robust iterate(`maxiter')
est2vec subshire_nosec13, addto(subshire_nosec13) name(logit)
est2vec subshire_nosec13, raddto(subshire_nosec13) name(logit)

clogit indhire `nosec13lst' `endog' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indprim & year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_nosec13, addto(subshire_nosec13) name(clogit_indprim)
est2vec subshire_nosec13, raddto(subshire_nosec13) name(clogit_indprim)

clogit indhire `nosec13lst' `endog' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indhigh & year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_nosec13, addto(subshire_nosec13) name(clogit_indhigh)
est2vec subshire_nosec13, raddto(subshire_nosec13) name(clogit_indhigh)

clogit indhire `nosec13lst' `endog' `cntrlfrm' `cntrlwrk' indsubs* indyr* if (indscoll | indgrad) & year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_nosec13, addto(subshire_nosec13) name(clogit_indcoll)
est2vec subshire_nosec13, raddto(subshire_nosec13) name(clogit_indcoll)

clogit indhire `nosec13lst' `endog' `cntrlfrm' `cntrlwrk' indsubs* indyr* if potexper < 10 & year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_nosec13, addto(subshire_nosec13) name(clogit_indyoung)
est2vec subshire_nosec13, raddto(subshire_nosec13) name(clogit_indyoung)

clogit indhire `nosec13lst' `endog' `cntrlfrm' `cntrlwrk' indsubs* subs_indprown_pis indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_nosec13, addto(subshire_nosec13) name(clogit_indprown)
est2vec subshire_nosec13, raddto(subshire_nosec13) name(clogit_indprown)

clogit indhire `nosec13lst' `endog' `cntrlfrm' `cntrlwrk' indsubs* occ_indoutsrc indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_nosec13, addto(subshire_nosec13) name(clogit_indoutsrc)
est2vec subshire_nosec13, raddto(subshire_nosec13) name(clogit_indoutsrc)

clogit indhire `nosec13lst' `endog' `cntrlfrm' `cntrlwrk' indsubs* firm_lnlp indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_nosec13, addto(subshire_nosec13) name(clogit_lnlp)
est2vec subshire_nosec13, raddto(subshire_nosec13) name(clogit_lnlp)
gen byte indpia = e(sample)
label var indpia "Indic.: In PIA (lnlp) sample"

clogit indhire `nosec13lst' `endog' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indpia, group(wid) robust iterate(`maxiter')
est2vec subshire_nosec13, addto(subshire_nosec13) name(clogit_ifpia)
est2vec subshire_nosec13, raddto(subshire_nosec13) name(clogit_ifpia)

xtreg firm_indexp `baseiv' `expiv' subs_balcadv `cntrlfrm' `cntrlwrk' indsubs* indyr* if indsmpl, fe i(wid)
est2vec subshire_nosec13, addto(subshire_nosec13) name(first_indexp)
test `baseiv' `expiv'
est2vec subshire_nosec13, raddto(subshire_nosec13) name(first_indexp)

xtreg subs_tarfoutp `baseiv' `expiv' subs_balcadv `cntrlfrm' `cntrlwrk' indsubs* indyr* if indsmpl, fe i(wid)
est2vec subshire_nosec13, addto(subshire_nosec13) name(first_tarfoutp)
test `baseiv' `expiv'
est2vec subshire_nosec13, raddto(subshire_nosec13) name(first_tarfoutp)

xtreg subs_tarfintm `baseiv' `expiv' subs_balcadv `cntrlfrm' `cntrlwrk' indsubs* indyr* if indsmpl, fe i(wid)
est2vec subshire_nosec13, addto(subshire_nosec13) name(first_tarfintm)
test `baseiv' `expiv'
est2vec subshire_nosec13, raddto(subshire_nosec13) name(first_tarfintm)

xtreg subs_reffpen `baseiv' `expiv' subs_balcadv `cntrlfrm' `cntrlwrk' indsubs* indyr* if indsmpl, fe i(wid)
est2vec subshire_nosec13, addto(subshire_nosec13) name(first_reffpen)
test `baseiv' `expiv'
est2vec subshire_nosec13, raddto(subshire_nosec13) name(first_reffpen)


// Save results

foreach type in b se e r {
  matsave subsdspl_nosec13_`type', p(brazrloc/estmat/v4/reg/natl) t(double) replace dropall
  matsave subshire_nosec13_`type', p(brazrloc/estmat/v4/reg/natl) t(double) replace dropall
  }

log close
