version 8.2
clear
set logtype text
set more off
set matsize 200

capture mkdir "brazrloc/estmat/v4/reg"
capture mkdir "brazrloc/estmat/v4/reg/natl"

capture log close
log using "brazrloc/logs/summary-stats-paper-natl.log", replace

local maxiter $maxiter


// SUBSIBGE REGRESSIONS

local paperlst "subs_balcadv firm_indexp"
local focallst "subs_balcadv firm_indexp"
local rehirlst "subs_balcadv_rehir firm_indexp_rehir"
local rehrendg "subs_tarfoutp_rehir subs_tarfintm_rehir subs_reffpen_rehir"
local cntrlfrm "subs_secrealx subs_fdiflw subs_herfsale plant_lnempl plant_indprim plant_indhigh plant_indwhittot"
local cntrlwrk "indprof indtech indwhit indsklb indfemal"
local cntrlreh "tenuryr potexper indprof indtech indwhit indsklb"
local endog    "subs_tarfoutp subs_tarfintm subs_reffpen"
local baseiv   "subs_dollar subs_ppieu subs_ppinam"
local expiv    "imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU"

* separations natl

use if ~indexcl using "brazrloc/data/separations-natl-subsibge.dta", clear

// load comparative advantage rank
gen byte subsibge = .
forvalues i = 1/26 {
  qui replace subsibge = `i' if indsubs_`i'==1
  }
sort subsibge year
merge subsibge year using "brazaux/intl/balassa-compadv-subsibge", nokeep
tab _m  // _m==1: workers in nontraded goods sectors
drop _merge subsibge wrld_exp wrld_tot braz_exp braz_tot balcadv

// redefinitions
gen plant_indcoll = 1 - plant_indhigh - plant_indprim
label var plant_indcoll "Share: College education"
gen byte indyoung = (potexper<10)
label var indyoung "Indic.: Pot. Exper. < 10yrs"
gen byte indnotprim = 1 - indprim
label var indnotprim "Indic.: High-sch. or college ed."
forvalues i = 1/13 {
  local year = 1985 + `i'
  label var indyr_`i' "Indic.: Year `year'"
  }
forvalues i = 1/26 {
  label var indsubs_`i' "Indic.: Subsector `i'"
  }

qui clogit inddspl `paperlst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(1)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In clogit sample"
tab year if indsmpl

summ subs_tarfoutp subs_tarfintm subs_reffpen if year==1990 & indsmpl
summ subs_tarfoutp subs_tarfintm subs_reffpen if year==1992 & indsmpl
summ subs_tarfoutp subs_tarfintm subs_reffpen if year==1994 & indsmpl
summ subs_tarfoutp subs_tarfintm subs_reffpen if year==1997 & indsmpl
summ subs_tarfoutp subs_tarfintm subs_reffpen if year==1998 & indsmpl

summ2tex * if indsmpl, c(mean sd N p50) path(brazrloc/estmat/v4/reg/natl) name(summ_dspl_allsec) replace detail
summ2tex * if indsmpl & balarank==1, c(mean sd N p50) path(brazrloc/estmat/v4/reg/natl) name(summ_dspl_balrnk1) replace detail
summ2tex * if indsmpl & balarank==3, c(mean sd N p50) path(brazrloc/estmat/v4/reg/natl) name(summ_dspl_balrnk3) replace detail
summ2tex * if indsmpl & balarank==5, c(mean sd N p50) path(brazrloc/estmat/v4/reg/natl) name(summ_dspl_balrnk5) replace detail
summ2tex * if indsmpl & firm_indexp, c(mean sd N p50) path(brazrloc/estmat/v4/reg/natl) name(summ_dspl_indexp) replace detail

preserve
mat summ_dspl_timevar_tbl = J(8,4,.)
mat rownames summ_dspl_timevar_tbl = plant_lnempl:1990 plant_lnempl:1992 plant_lnempl:1994 plant_lnempl:1998 firm_lnlp:1990 firm_lnlp:1992 firm_lnlp:1994 firm_lnlp:1998
mat colnames summ_dspl_timevar_tbl = mean:allsec sd:allsec mean:balarank5 mean:firm_indexp
foreach var in plant_lnempl firm_lnlp {
  foreach yr in 90 92 94 98 {
    qui summ `var' if year==19`yr'
    mat summ_dspl_timevar_tbl[rownumb(summ_dspl_timevar_tbl,"`var':19`yr'"),colnumb(summ_dspl_timevar_tbl,"mean:allsec")] = `r(mean)'
    mat summ_dspl_timevar_tbl[rownumb(summ_dspl_timevar_tbl,"`var':19`yr'"),colnumb(summ_dspl_timevar_tbl,"sd:allsec")] = `r(sd)'
    qui summ `var' if year==19`yr' & balarank==5, meanonly
    mat summ_dspl_timevar_tbl[rownumb(summ_dspl_timevar_tbl,"`var':19`yr'"),colnumb(summ_dspl_timevar_tbl,"mean:balarank5")] = `r(mean)'
    qui summ `var' if year==19`yr' & firm_indexp, meanonly
    mat summ_dspl_timevar_tbl[rownumb(summ_dspl_timevar_tbl,"`var':19`yr'"),colnumb(summ_dspl_timevar_tbl,"mean:firm_indexp")] = `r(mean)'
    }
  }
est2tex summ_dspl_timevar, ready dropall path(brazrloc/estmat/v4/reg/natl) replace
restore

keep cnpj_radic year firm_indexp balarank indsmpl
bysort cnpj_radic year indsmpl: keep if _n==1
collapse (sum) firm_indexp if indsmpl, by(balarank year) fast
list

* accessions natl

use if ~indexcl using "brazrloc/data/accessions-natl-subsibge.dta", clear

// load comparative advantage rank
gen byte subsibge = .
forvalues i = 1/26 {
  qui replace subsibge = `i' if indsubs_`i'==1
  }
sort subsibge year
merge subsibge year using "brazaux/intl/balassa-compadv-subsibge", nokeep
tab _m  // _m==1: workers in nontraded goods sectors
drop _merge subsibge wrld_exp wrld_tot braz_exp braz_tot balcadv

// redefinitions
gen plant_indcoll = 1 - plant_indhigh - plant_indprim
label var plant_indcoll "Share: College education"
gen byte indyoung = (potexper<10)
label var indyoung "Indic.: Pot. Exper. < 10yrs"
gen byte indnotprim = 1 - indprim
label var indnotprim "Indic.: High-sch. or college ed."
forvalues i = 1/13 {
  local year = 1985 + `i'
  label var indyr_`i' "Indic.: Year `year'"
  }
forvalues i = 1/26 {
  label var indsubs_`i' "Indic.: Subsector `i'"
  }

qui clogit indhire `paperlst' `endog' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(1)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In clogit sample"
tab year if indsmpl

summ subs_tarfoutp subs_tarfintm subs_reffpen if year==1990 & indsmpl
summ subs_tarfoutp subs_tarfintm subs_reffpen if year==1992 & indsmpl
summ subs_tarfoutp subs_tarfintm subs_reffpen if year==1994 & indsmpl
summ subs_tarfoutp subs_tarfintm subs_reffpen if year==1997 & indsmpl
summ subs_tarfoutp subs_tarfintm subs_reffpen if year==1998 & indsmpl

summ2tex * if indsmpl, c(mean sd N p50) path(brazrloc/estmat/v4/reg/natl) name(summ_hire_allsec) replace detail
summ2tex * if indsmpl & balarank==1, c(mean sd N p50) path(brazrloc/estmat/v4/reg/natl) name(summ_hire_balrnk1) replace detail
summ2tex * if indsmpl & balarank==3, c(mean sd N p50) path(brazrloc/estmat/v4/reg/natl) name(summ_hire_balrnk3) replace detail
summ2tex * if indsmpl & balarank==5, c(mean sd N p50) path(brazrloc/estmat/v4/reg/natl) name(summ_hire_balrnk5) replace detail
summ2tex * if indsmpl & firm_indexp, c(mean sd N p50) path(brazrloc/estmat/v4/reg/natl) name(summ_hire_indexp) replace detail

preserve
mat summ_hire_timevar_tbl = J(8,4,.)
mat rownames summ_hire_timevar_tbl = plant_lnempl:1990 plant_lnempl:1992 plant_lnempl:1994 plant_lnempl:1998 firm_lnlp:1990 firm_lnlp:1992 firm_lnlp:1994 firm_lnlp:1998
mat colnames summ_hire_timevar_tbl = mean:allsec sd:allsec mean:balarank5 mean:firm_indexp
foreach var in plant_lnempl firm_lnlp {
  foreach yr in 90 92 94 98 {
    qui summ `var' if year==19`yr'
    mat summ_hire_timevar_tbl[rownumb(summ_hire_timevar_tbl,"`var':19`yr'"),colnumb(summ_hire_timevar_tbl,"mean:allsec")] = `r(mean)'
    mat summ_hire_timevar_tbl[rownumb(summ_hire_timevar_tbl,"`var':19`yr'"),colnumb(summ_hire_timevar_tbl,"sd:allsec")] = `r(sd)'
    qui summ `var' if year==19`yr' & balarank==5, meanonly
    mat summ_hire_timevar_tbl[rownumb(summ_hire_timevar_tbl,"`var':19`yr'"),colnumb(summ_hire_timevar_tbl,"mean:balarank5")] = `r(mean)'
    qui summ `var' if year==19`yr' & firm_indexp, meanonly
    mat summ_hire_timevar_tbl[rownumb(summ_hire_timevar_tbl,"`var':19`yr'"),colnumb(summ_hire_timevar_tbl,"mean:firm_indexp")] = `r(mean)'
    }
  }
est2tex summ_hire_timevar, ready dropall path(brazrloc/estmat/v4/reg/natl) replace
restore

keep cnpj_radic year firm_indexp balarank indsmpl
bysort cnpj_radic year indsmpl: keep if _n==1
collapse (sum) firm_indexp if indsmpl, by(balarank year) fast
list

* hazard natl

use if ~indexcl using "brazrloc/data/hazard-durations-natl-subsibge.dta", clear

// introduce time variable for panel structure; censor at 12/31/2001
gen int rehirtim = mdy((mes_desl+mo2rehir)-int((mes_desl+mo2rehir-.1)/12)*12,15,year+int((mes_desl+mo2rehir-.1)/12))
format rehirtim %dD/M/CY
label var rehirtim "Date of rehiring"
by wid: gen byte indreall = (mo2rehir~=.)
label var indreall "Indic.: Successful reallocation"
qui replace rehirtim = mdy(12,31,2001) if rehirtim==. & ~indreall

// stset: displacement on 14th (16th) of month, first (second) rehiring on 15th (17th) of month; days rescaled to months with 365.25/12
local scale = 365.25/12
local strt1986 = mdy(1,14,1986) // 9510
local strt1990 = mdy(1,14,1990)
local tmin1990 = (mdy(1,14,1990) - `strt1986')/`scale' // (10971-9510)/30.4375 = 1461/30.4375
qui by wid: replace rehirtim = rehirtim+2 if rehirtim[_n-1]==rehirtim  // problem cases with displacement immediately following rehiring
stset rehirtim, id(wid) failure(indreall) origin(time `strt1986') enter(time mdy(mes_desl,14,year)) exit(time .) scale(`scale')
order wid year* mes_deslig rehirtim mo2rehir rehircat inddisc subs_balcadv* subs_fdiflw* subs_reffpen* subs_tarfoutp* subs_tarfintm* subs_herfsale* subs_indprown_pis* occ_indoutsrc plant_lnempl plant_indprim plant_indhigh plant_indwhittot firm_indexp* firm_lnlp* tenuryr potexper indprim indhigh indscoll indgrad indprof indtech indwhit indsklb indunsklb subs_dollar* subs_ppieu* subs_ppinam* subs_secrealx*
sort wid year year_rehir
stset rehirtim, id(wid) failure(indreall) origin(time `strt1990') enter(time mdy(mes_desl,14,year)) exit(time .) scale(`scale')

// redefinitions
gen plant_indcoll = 1 - plant_indhigh - plant_indprim
label var plant_indcoll "Share: College education"
gen byte indyoung = (potexper<10)
label var indyoung "Indic.: Pot. Exper. < 10yrs"
gen byte indnotprim = 1 - indprim
label var indnotprim "Indic.: High-sch. or college ed."

gen byte subsibge = .
forvalues i = 1/26 {
  qui replace subsibge = `i' if indsubs_`i'==1
  }
sort subsibge year
merge subsibge year using "brazaux/intl/balassa-compadv-subsibge", nokeep
tab _m  // _m==1: workers in nontraded goods sectors
drop _merge subsibge wrld_exp wrld_tot braz_exp braz_tot balcadv
forvalues i = 1/13 {
  local year = 1985 + `i'
  label var indyr_`i' "Indic.: Year `year'"
  }
forvalues i = 1/26 {
  label var indsubs_`i' "Indic.: Subsector `i'"
  }

qui streg `rehirlst' `rehrendg' `focallst' `endog' `cntrlfrm' `cntrlreh' indyr* if year>=1990 & rehircat<=4, dist(gamma) robust iterate(1)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In streg sample"
tab year if indsmpl

summ subs_tarfoutp subs_tarfintm subs_reffpen if year==1990 & indsmpl
summ subs_tarfoutp subs_tarfintm subs_reffpen if year==1992 & indsmpl
summ subs_tarfoutp subs_tarfintm subs_reffpen if year==1994 & indsmpl
summ subs_tarfoutp subs_tarfintm subs_reffpen if year==1997 & indsmpl
summ subs_tarfoutp subs_tarfintm subs_reffpen if year==1998 & indsmpl

summ2tex * if indsmpl, c(mean sd N p50) path(brazrloc/estmat/v4/reg/natl) name(summ_hzrd_allsec) replace detail
summ2tex * if indsmpl & balarank==1, c(mean sd N p50) path(brazrloc/estmat/v4/reg/natl) name(summ_hzrd_balrnk1) replace detail
summ2tex * if indsmpl & balarank==3, c(mean sd N p50) path(brazrloc/estmat/v4/reg/natl) name(summ_hzrd_balrnk3) replace detail
summ2tex * if indsmpl & balarank==5, c(mean sd N p50) path(brazrloc/estmat/v4/reg/natl) name(summ_hzrd_balrnk5) replace detail
summ2tex * if indsmpl & firm_indexp, c(mean sd N p50) path(brazrloc/estmat/v4/reg/natl) name(summ_hzrd_indexp) replace detail

preserve
mat summ_hzrd_timevar_tbl = J(8,4,.)
mat rownames summ_hzrd_timevar_tbl = plant_lnempl:1990 plant_lnempl:1992 plant_lnempl:1994 plant_lnempl:1998 firm_lnlp:1990 firm_lnlp:1992 firm_lnlp:1994 firm_lnlp:1998
mat colnames summ_hzrd_timevar_tbl = mean:allsec sd:allsec mean:balarank5 mean:firm_indexp
foreach var in plant_lnempl firm_lnlp {
  foreach yr in 90 92 94 98 {
    qui summ `var' if year==19`yr'
    mat summ_hzrd_timevar_tbl[rownumb(summ_hzrd_timevar_tbl,"`var':19`yr'"),colnumb(summ_hzrd_timevar_tbl,"mean:allsec")] = `r(mean)'
    mat summ_hzrd_timevar_tbl[rownumb(summ_hzrd_timevar_tbl,"`var':19`yr'"),colnumb(summ_hzrd_timevar_tbl,"sd:allsec")] = `r(sd)'
    qui summ `var' if year==19`yr' & balarank==5, meanonly
    mat summ_hzrd_timevar_tbl[rownumb(summ_hzrd_timevar_tbl,"`var':19`yr'"),colnumb(summ_hzrd_timevar_tbl,"mean:balarank5")] = `r(mean)'
    qui summ `var' if year==19`yr' & firm_indexp, meanonly
    mat summ_hzrd_timevar_tbl[rownumb(summ_hzrd_timevar_tbl,"`var':19`yr'"),colnumb(summ_hzrd_timevar_tbl,"mean:firm_indexp")] = `r(mean)'
    }
  }
est2tex summ_hzrd_timevar, ready dropall path(brazrloc/estmat/v4/reg/natl) replace
restore

keep cnpj_radic year firm_indexp balarank indsmpl
bysort cnpj_radic year indsmpl: keep if _n==1
collapse (sum) firm_indexp if indsmpl, by(balarank year) fast
list

log close
