version 8
set more off
set virtual on
clear
set trace off

cd "$root"

capture mkdir "brazrloc/simul"
capture mkdir "brazrloc/simul/v4"
capture mkdir "brazrloc/graphs"
capture mkdir "brazrloc/graphs/v4"
capture mkdir "brazrloc/graphs/v4/natl"
capture mkdir "brazrloc/graphs/v4/natl/simul"

capture log close
log using "brazrloc/logs/connect-stats-natl.log", replace


* EMPLOYMENT AND NONEMPLOYMENT SIMULATIONS

* load data
foreach dur in 12 48 { /* 12 or 48 */
local strtyr = 1986 + `dur'/12
local finlyr = 2001 - `dur'/12

use "brazrloc/simul/v4/norlc-yr`dur'", clear
foreach var of varlist empl duplobs inddspl indhire {
  rename `var' norlc_cal_`var'
  }
merge ano month using "brazrloc/simul/v4/morhr-yr`dur'"
foreach var of varlist empl duplobs inddspl indhire {
  rename `var' morhr_cal_`var'
  }
drop if _m~=3
drop _m
* gen strmo = string(ano) + "m" + string(month)
gen int statmo = _n + (1986-1960)*12 - 1
label var statmo "Calendar month"
order statmo ano month
tsset statmo, monthly
order statmo ano month indnorloc infer_indnorloc mo2rehir infer_mo2rehir norloc_inddspl mo2rhr_inddspl norloc_indhire mo2rhr_indhire norlc_cal_empl morhr_cal_empl norlc_cal_duplobs morhr_cal_duplobs norlc_cal_inddspl morhr_cal_inddspl norlc_cal_indhire morhr_cal_indhire 
compare indnorloc infer_indnorloc
compare mo2rehir infer_mo2rehir
compare norlc_cal_empl morhr_cal_empl 
compare norlc_cal_duplobs morhr_cal_duplobs
compare norlc_cal_inddspl morhr_cal_inddspl
compare norlc_cal_indhire morhr_cal_indhire
foreach var in empl duplobs inddspl indhire {
  rename norlc_cal_`var' `var'
  drop morhr_cal_`var'
  }
sort ano month
merge ano month using "brazrloc/simul/v4/find-yr`dur'"
tab _m
qui count if _m~=3  
if `r(N)'>0  STOP
drop _m
tsset statmo, monthly

* consistency between failure rate, findings rates and accession rates
qui tab ano, gen(indano)
qui tab month, gen(indmo)
rename infer_indfind indfind
gen byfind_indnorloc = (1-indfind) * (1-f1.indfind) * (1-f2.indfind) * (1-f3.indfind) * (1-f4.indfind) * (1-f5.indfind) * (1-f6.indfind) * (1-f7.indfind) * (1-f8.indfind) * (1-f9.indfind) * (1-f10.indfind) * (1-f11.indfind) * (1-f12.indfind)
label var byfind_indnorloc "(1-indfind) * (1-f1.indfind) * ... * (1-f12.indfind)"
gen adjfind_norloc = byfind_indnorloc/indnorloc
label var adjfind_norloc "byfind_indnorloc/indnorloc"
reg adjfind_norloc indano* indmo*, nocons
gen byhire_indnorloc = (1-indhire) * (1-f1.indhire) * (1-f2.indhire) * (1-f3.indhire) * (1-f4.indhire) * (1-f5.indhire) * (1-f6.indhire) * (1-f7.indhire) * (1-f8.indhire) * (1-f9.indhire) * (1-f10.indhire) * (1-f11.indhire) * (1-f12.indhire)
label var byhire_indnorloc "(1-indhire) * (1-f1.indhire) * ... * (1-f12.indhire)"
gen adjhire_norloc = byhire_indnorloc/indnorloc
label var adjhire_norloc "byhire_indnorloc/indnorloc"
reg adjhire_norloc indano* indmo*, nocons
gen nonempl_empl = indhire/indfind
label var nonempl_empl "indhire/indfind"
reg nonempl_empl indano* indmo*, nocons
graph twoway connected inddspl indhire statmo if ano>=`strtyr' & ano<=`finlyr', ytitle("Frequency") legend( label(1 "Separation rate") label(2 "Accession rate") ) graphregion(color(white)) scheme(sj) msymbol(T i i i) clpattern(solid dash_dot solid dash)
graph export "brazrloc/graphs/v4/natl/simul/dsplhire`dur'm.eps", replace
more
graph twoway connected indfind indhire statmo if ano>=`strtyr' & ano<=`finlyr', ytitle("Frequency") legend( label(1 "Job finding rate") label(2 "Accession rate") ) graphregion(color(white)) scheme(sj) msymbol(T i i i) clpattern(solid dash_dot solid dash)
graph export "brazrloc/graphs/v4/natl/simul/findhire`dur'm.eps", replace
more

* employment and nonemployment time series
gen totempl = (empl - duplobs) * 100 /1000000  // Employment in million head counts (adjusting for 1-percent sampling rate)
label var totempl "(empl-duplobs)*100/1000000" 
gen predempl = totempl[_n-1] + indhire*totempl - inddspl[_n-1]*totempl[_n-1]
label var predempl "totempl[_n-1] + indhire*totempl - inddspl[_n-1]*totempl[_n-1]" 
gen devempl = predempl/totempl - 1
label var devempl "predempl/totempl - 1 
gen totnonempl = nonempl_empl * totempl
label var totnonempl "nonempl_empl*totempl"
graph twoway connected totempl totnonempl statmo if ano>=`strtyr' & ano<=`finlyr', ytitle("Million persons") legend( label(1 "Employment (observed)") label(2 "Nonemployment (model)") ) graphregion(color(white)) scheme(sj) msymbol(T i i i) clpattern(solid dash_dot solid dash)
graph export "brazrloc/graphs/v4/natl/simul/totnonempl`dur'm.eps", replace
more

* regressions
gen lnindnorloc = log(indnorloc)
gen ln1lsindhire = log(1-indhire)
gen ln1lsindfind = log(1-indfind)
reg devempl indmo*, nocons
reg devempl indano* indmo*, nocons
if `dur'==12  reg lnindnorloc ln1lsindhire f1.ln1lsindhire f2.ln1lsindhire f3.ln1lsindhire f4.ln1lsindhire f5.ln1lsindhire f6.ln1lsindhire f7.ln1lsindhire f8.ln1lsindhire f9.ln1lsindhire f10.ln1lsindhire f11.ln1lsindhire f12.ln1lsindhire, nocons
if `dur'==48  reg lnindnorloc ln1lsindhire f1.ln1lsindhire f2.ln1lsindhire f3.ln1lsindhire f4.ln1lsindhire f5.ln1lsindhire f6.ln1lsindhire f7.ln1lsindhire f8.ln1lsindhire f9.ln1lsindhire f10.ln1lsindhire f11.ln1lsindhire f12.ln1lsindhire f13.ln1lsindhire f14.ln1lsindhire f15.ln1lsindhire f16.ln1lsindhire f17.ln1lsindhire f18.ln1lsindhire f19.ln1lsindhire f20.ln1lsindhire f21.ln1lsindhire f22.ln1lsindhire f23.ln1lsindhire f24.ln1lsindhire f25.ln1lsindhire f26.ln1lsindhire f27.ln1lsindhire f28.ln1lsindhire f29.ln1lsindhire f30.ln1lsindhire f31.ln1lsindhire f32.ln1lsindhire f33.ln1lsindhire f34.ln1lsindhire f35.ln1lsindhire f36.ln1lsindhire f37.ln1lsindhire f38.ln1lsindhire f39.ln1lsindhire f40.ln1lsindhire f41.ln1lsindhire f42.ln1lsindhire f43.ln1lsindhire f44.ln1lsindhire f45.ln1lsindhire f46.ln1lsindhire f47.ln1lsindhire f48.ln1lsindhire, nocons
if `dur'==12  reg lnindnorloc ln1lsindfind f1.ln1lsindfind f2.ln1lsindfind f3.ln1lsindfind f4.ln1lsindfind f5.ln1lsindfind f6.ln1lsindfind f7.ln1lsindfind f8.ln1lsindfind f9.ln1lsindfind f10.ln1lsindfind f11.ln1lsindfind f12.ln1lsindfind, nocons
if `dur'==48  reg lnindnorloc ln1lsindfind f1.ln1lsindfind f2.ln1lsindfind f3.ln1lsindfind f4.ln1lsindfind f5.ln1lsindfind f6.ln1lsindfind f7.ln1lsindfind f8.ln1lsindfind f9.ln1lsindfind f10.ln1lsindfind f11.ln1lsindfind f12.ln1lsindfind f13.ln1lsindfind f14.ln1lsindfind f15.ln1lsindfind f16.ln1lsindfind f17.ln1lsindfind f18.ln1lsindfind f19.ln1lsindfind f20.ln1lsindfind f21.ln1lsindfind f22.ln1lsindfind f23.ln1lsindfind f24.ln1lsindfind f25.ln1lsindfind f26.ln1lsindfind f27.ln1lsindfind f28.ln1lsindfind f29.ln1lsindfind f30.ln1lsindfind f31.ln1lsindfind f32.ln1lsindfind f33.ln1lsindfind f34.ln1lsindfind f35.ln1lsindfind f36.ln1lsindfind f37.ln1lsindfind f38.ln1lsindfind f39.ln1lsindfind f40.ln1lsindfind f41.ln1lsindfind f42.ln1lsindfind f43.ln1lsindfind f44.ln1lsindfind f45.ln1lsindfind f46.ln1lsindfind f47.ln1lsindfind f48.ln1lsindfind, nocons

drop lnindnorloc ln1lsindhire ln1lsindfind indano* indmo* 
compress
order statmo
sort statmo
save "brazrloc/simul/v4/connect-stats-natl-`dur'm", replace


* COMPARISONS BETWEEN MONTHLY AND ANNUAL DATA

foreach var of varlist inddspl indhire indfind indnorloc mo2rehir totempl totnonempl {
  local `var' : variable label `var'
  }
collapse (mean) inddspl indhire indfind indnorloc mo2rehir totempl totnonempl, by(ano) fast
foreach var of varlist inddspl indhire indfind indnorloc mo2rehir totempl totnonempl {
  label var `var' "``var''"
  rename `var' mo_`var'
  }
merge using "brazrloc/tex/v4/natl/duration/indnorloc`dur'm_tbl.dta"
rename _rowname ano_indnorlc
label var indnorloc "Sh: Failed reallocations"
qui count if ano_indnorlc~=string(ano) & ano_indnorlc~=""
if `r(N)'>0  STOP  // bad merge
drop _m ano_indnorlc
merge using "brazrloc/tex/v4/natl/duration/mo2rehr`dur'm_tbl.dta"
rename _rowname ano_mo2rhr
label var mo2rehir "Mean: Reallocation durations"
qui count if ano_mo2rhr~=string(ano) & ano_mo2rhr~=""
if `r(N)'>0  STOP  // bad merge
drop _m ano_mo2rhr
order ano mo_inddspl mo_indhire mo_indfind mo_indnorloc indnorloc mo_mo2rehir mo2rehir
compare mo_indnorloc indnorloc
compare mo_mo2rehir mo2rehir
graph twoway connected mo_inddspl mo_indhire ano if ano>=`strtyr' & ano<=`finlyr', xlab(`strtyr'/`finlyr') ytitle("Frequency") legend( label(1 "Separation rate") label(2 "Accession rate") ) graphregion(color(white)) scheme(sj) msymbol(T i i i) clpattern(solid dash_dot solid dash)
graph export "brazrloc/graphs/v4/natl/simul/dsplhire`dur'm-annual.eps", replace
more
graph twoway connected mo_indfind mo_indhire ano if ano>=`strtyr' & ano<=`finlyr', xlab(`strtyr'/`finlyr') ytitle("Frequency") legend( label(1 "Job finding rate") label(2 "Accession rate") ) graphregion(color(white)) scheme(sj) msymbol(T i i i) clpattern(solid dash_dot solid dash)
graph export "brazrloc/graphs/v4/natl/simul/findhire`dur'm-annual.eps", replace
more
graph twoway connected mo_totempl mo_totnonempl ano if ano>=`strtyr' & ano<=`finlyr', xlab(`strtyr'/`finlyr') ytitle("Million persons") legend( label(1 "Employment (observed)") label(2 "Nonemployment (model)") ) graphregion(color(white)) scheme(sj) msymbol(T i i i) clpattern(solid dash_dot solid dash)
graph export "brazrloc/graphs/v4/natl/simul/totnonempl`dur'm-annual.eps", replace
more


* COMPARISONS TO REGRESSION DATA

preserve
  tempfile regdspl
  use if ~indexcl using "brazrloc/data/separations-natl-subsibge-10pct", clear
  collapse (mean) inddspl, by(year)
  label var inddspl "Separation Rate (10pct smpl)"
  sort year
  rename year ano
  save `regdspl'
restore, preserve
  tempfile reghire
  use if ~indexcl using "brazrloc/data/accessions-natl-subsibge-10pct", clear
  collapse (mean) indhire, by(year)
  label var indhire "Accession Rate (10pct smpl)"
  sort year
  rename year ano
  save `reghire'
restore
sort ano
merge ano using  `regdspl'
drop _m
sort ano
merge ano using  `reghire'
drop _m

graph twoway connected mo_inddspl inddspl ano if ano>=`strtyr' & ano<=`finlyr', xlab(`strtyr'/`finlyr') ytitle("Separation rate (frequency)") legend( label(1 "Average monthly rate") label(2 "Per-year rate") ) graphregion(color(white)) scheme(sj) msymbol(T i i i) clpattern(solid dash_dot solid dash)
graph export "brazrloc/graphs/v4/natl/simul/compdspl`dur'm-annual.eps", replace
more
graph twoway connected mo_indhire indhire ano if ano>=`strtyr' & ano<=`finlyr', xlab(`strtyr'/`finlyr') ytitle("Accessions rate (frequency)") legend( label(1 "Average monthly rate") label(2 "Per-year rate") ) graphregion(color(white)) scheme(sj) msymbol(T i i i) clpattern(solid dash_dot solid dash)
graph export "brazrloc/graphs/v4/natl/simul/comphire`dur'm-annual.eps", replace
more

compress
order ano
sort ano
save "brazrloc/simul/v4/connect-stats-natl-`dur'm-annual", replace

}  // end `dur' loop

log close
cd "$root"

