version 8
set more off
set virtual on
clear
set trace off

cd "$root"

capture mkdir "brazrloc/simul"
capture mkdir "brazrloc/simul/v4"

capture log close
log using "brazrloc/logs/monthly-stat-natl.log", replace

foreach dur in 12 48 {  // preparation code as in brazrloc/%stata/%2tab-graph/durations-natl.do

* REALLOCATION FAILURES AND MONTHLY SEPARATION AND ACCESSION RATES

use wid ano mes_adm mes_deslig identificad caus_desl_tc tipo_adm fx_etaria sexo occagg grau_instr rem_media subs_ibge clas_cnae_95 temp_empr using "brazrloc/data/wid-draw-workers-natl", clear
gen byte indfemal = (sexo==2) // female workers
label var indfemal "Indic.: Female worker"
drop sexo
qui gen byte indany   = 1
label var indany   "Indic.: Full sample"
qui gen byte indskloc = (occagg < 4)
label var indskloc "Indic.: White collar"

* update sector information with CNAE in 1994-2001 (563 industries), keep subsibge information for 1986-1993 (26 sectors)
gen long cnaemix = clas_cnae_95 // CNAE sector information in 1994-2001
replace cnaemix = subs_ibge if ano<=1993  // keep subsibge information for 1986-1993
label var cnaemix "Subsibge 1986-93, CNAE 94-2001"

* potential experience
qui gen workrage = 12 if fx_etaria==1
qui replace workrage =   16 if fx_etaria==2
qui replace workrage =   21 if fx_etaria==3
qui replace workrage =   27 if fx_etaria==4
qui replace workrage = 34.5 if fx_etaria==5
qui replace workrage = 44.5 if fx_etaria==6
qui replace workrage =   57 if fx_etaria==7
qui replace workrage =   .  if fx_etaria==8
label var workrage "Mid-point age in age group"
qui gen potexper     = workrage -  6 if grau_instr==1
qui replace potexper = workrage -  7 if grau_instr==2
qui replace potexper = workrage - 10 if grau_instr==3
qui replace potexper = workrage - 11 if grau_instr==4
qui replace potexper = workrage - 14 if grau_instr==5
qui replace potexper = workrage - 15 if grau_instr==6
qui replace potexper = workrage - 18 if grau_instr==7
qui replace potexper = workrage - 19 if grau_instr==8
qui replace potexper = workrage - 22 if grau_instr==9
qui label var potexper "Potential labor force experience"
qui gen byte indyoung = (potexper < 10)
label var indyoung "Indic.: 10 yrs or less exprienc."
drop workrage fx_etaria potexper

* education indicators
qui gen byte indprim = (grau_instr==1 | grau_instr==2 | grau_instr==3 | grau_instr==4 | grau_instr==5)
label var indprim "Primary or Middle School Educ."
qui gen byte indhigh = (grau_instr==6 | grau_instr==7)
label var indhigh "High School Education"
qui gen byte indcoll = (grau_instr==8 | grau_instr==9)
label var indcoll "College Education"
qui gen byte indnotprim = 1 - indprim
label var indnotprim "High School or College Educ."
drop grau_instr

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.
sort wid ano mes_adm mes_deslig identificad

* identify accession (excluding transfer)
gen byte indhire = (mes_adm > 0 & tipo_adm~=0 & tipo_adm~=3 & tipo_adm~=4)
label var indhire "Indic.: Accession"
egen norloc_indhire = mean(indhire), by(ano mes_desl cnaemix)

* identify displacement and month of first rehiring
gen byte inddspl = (mes_deslig < 13 & caus_desl~=0 & caus_desl~=6 & caus_desl~=7 & caus_desl~=8)
by wid: gen str7 morehir = string(mes_adm[_n+1]) + "/" + string(ano[_n+1]) if inddspl==1
by wid: gen tenratrehr = temp_empr[_n+1] if inddspl==1
by wid: gen mesdeslinrehryr = mes_desl[_n+1] if inddspl==1
label var inddspl "Indic.: Displacement"
label var morehir "Month of first rehiring"
egen norloc_inddspl = mean(inddspl), by(ano mes_desl cnaemix)

* calculate months from displacement to first rehiring, if within 12 or 48
gen mo2rehir = (int(real(substr(morehir,-4,4))) - ano)*12 + (int(real(substr(morehir,1,index(morehir,"/")-1))) - mes_desl)
replace mo2rehir = 0 if int(real(substr(morehir,-4,4)))==ano & int(real(substr(morehir,1,index(morehir,"/")-1)))<mes_desl
replace mo2rehir = . if mo2rehir>`dur'
label var mo2rehir "Months to re-employment"

* job-finding counts and rates
preserve
  tempfile infer infrhrsecyr`dur' infrhryr`dur' infnorsecyr`dur' infnoryr`dur' findratesec findrate
  keep wid ano mes_desl morehir mo2rehir tenratrehr mesdeslinrehryr cnaemix inddspl
  gen int rhryear = int(real(substr(morehir,-4,4)))
  gen byte rhrmonth = int(real(substr(morehir,1,index(morehir,"/")-1)))
  gen int rhrmo = (rhryear-1960)*12 + rhrmonth - 1
  label var rhrmo "Month of first rehiring"
  gen int infer_rhrmo = (rhryear-1960)*12 + mesdeslinrehryr-1 - tenratrehr - 1
  label var infer_rhrmo "Tenure-adj. Mo. of first rehiring (`dur' mo.)"
  gen int dsplmo = (ano-1960)*12 + mes_deslig - 1 if inddspl==1
  label var dsplmo "Month of displacement"
  format rhrmo infer_rhrmo dsplmo %tm
  replace rhrmo = rhrmo+1 if rhrmonth==0
  replace infer_rhrmo = dsplmo if dsplmo>infer_rhrmo
  gen infer_mo2rehir = infer_rhrmo - dsplmo
  replace infer_mo2rehir = . if mo2rehir>`dur'
  if `dur'==12  replace infer_mo2rehir = . if ano>=2001
  if `dur'==48  replace infer_mo2rehir = . if ano>=1998
  drop rhryear rhrmonth
  order wid ano cnaemix mes_deslig dsplmo morehir tenratrehr mesdeslinrehryr rhrmo infer_rhrmo mo2rehir infer_mo2rehir
  egen cntdspl = count(wid), by(dsplmo)
  egen cntdspl_sec = count(wid), by(dsplmo cnaemix)
  label var cntdspl "# Displacements [by dsplmo]"
  label var cntdspl_sec "# Sector Displacements [by dsplmo]"
  keep if morehir~="" & morehir~="./."
  drop if mo2rehir == . & infer_mo2rehir==. // mo2rehir>`dur'
  qui count if  (mo2rehir==. &  infer_mo2rehir~=.) | (mo2rehir~=. &  infer_mo2rehir==.)
  disp in gr "Tenure-adj. and unadj. durations  with different non-missing/missing: " in ye `r(N)'
  * if `r(N)'>0  STOP  // contradictory durations
  sort wid ano mes_deslig
  compress
  save `infer'

  * inferred (tenure-adjusted) months to rehiring, sector level and annual
  rename mes_deslig month
  collapse (mean) infer_mo2rehir, by(ano month cnaemix) fast
  label var infer_mo2rehir "Tenure-adj. mo. to re-empl. (`dur' mo.)"
  compress
  sort ano month cnaemix
  save `infrhrsecyr`dur''
  collapse (mean) infer_mo2rehir, by(ano month) fast
  label var infer_mo2rehir "Tenure-adj. mo. to re-empl. (`dur' mo.)"
  compress
  sort ano month
  save `infrhryr`dur''

  * finding rates and inferred (tenure-adjusted) reallocation failures, sector level
  use `infer', clear
  egen cntdsplrehr_sec = count(wid), by(dsplmo cnaemix)
  label var cntdsplrehr_sec "# Rehired of Sector displaced [by dsplmo]"
  collapse (count) cntfind_sec=wid (mean) cntdspl_sec cntdsplrehr_sec, by(infer_rhrmo dsplmo cnaemix) fast
  label var cntfind_sec "# Job finding spells Sector"
  label var cntdspl_sec "# Sector Displacements [by dsplmo]"
  label var cntdsplrehr_sec "# Rehired of Sector displaced [by dsplmo]"
  sort dsplmo infer_rhrmo
  gen indnorloc_sec = 1 - cntdsplrehr_sec/cntdspl_sec
  if `dur'==12  replace indnorloc_sec = . if int(dsplmo/12 + 1960)>=2001
  if `dur'==48  replace indnorloc_sec = . if int(dsplmo/12 + 1960)>=1998
  label var indnorloc_sec "Indic.: No reall. from Sector in `dur' months"
  sort infer_rhrmo dsplmo
  egen indfind_sec = mean(cntfind_sec/cntdspl_sec), by(infer_rhrmo cnaemix)
  if `dur'==12  replace indfind_sec = . if int(infer_rhrmo/12 + 1960)<=1986
  if `dur'==48  replace indfind_sec = . if int(infer_rhrmo/12 + 1960)<=1989
  label var indfind_sec "Sh: Findings (sector displaced upto `dur' mo. ago)"
  sort infer_rhrmo dsplmo cnaemix
  save `findratesec'
  keep dsplmo cnaemix indnorloc_sec
  qui duplicates drop
  gen int ano = int(dsplmo/12 + 1960)
  gen month = dsplmo - (ano-1960)*12 + 1
  drop dsplmo
  rename indnorloc_sec infer_indnorloc
  label var infer_indnorloc "Tenure-adj. Sh: Failed reall. (`dur' mo.)"
  order ano month cnaemix infer_indnorloc
  label var ano "Calendar year"
  label var month "Calendar month"
  compress
  sort ano month cnaemix
  save `infnorsecyr`dur''
  use `findratesec'
  keep infer_rhrmo cnaemix indfind_sec
  qui duplicates drop
  gen int ano = int(infer_rhrmo/12 + 1960)
  gen month = infer_rhrmo - (ano-1960)*12 + 1
  drop infer_rhrmo
  rename indfind_sec infer_indfind
  order ano month cnaemix infer_indfind
  label var ano "Calendar year"
  label var month "Calendar month"
  compress
  sort ano month cnaemix
  save "brazrloc/simul/v4/find-secyr`dur'", replace

  * finding rates and inferred (tenure-adjusted) reallocation failures, annual
  use `infer', clear
  egen cntdsplrehr = count(wid), by(dsplmo)
  label var cntdsplrehr "# Rehired of displaced [by dsplmo]"
  collapse (count) cntfind=wid (mean) cntdspl cntdsplrehr, by(infer_rhrmo dsplmo) fast
  label var cntfind "# Job finding spells"
  label var cntdspl "# Displacements [by dsplmo]"
  label var cntdsplrehr "# Rehired of displaced [by dsplmo]"
  sort dsplmo infer_rhrmo
  gen indnorloc = 1 - cntdsplrehr/cntdspl
  if `dur'==12  replace indnorloc = . if int(dsplmo/12 + 1960)>=2001
  if `dur'==48  replace indnorloc = . if int(dsplmo/12 + 1960)>=1998
  label var indnorloc "Indic.: No reall. in `dur' months"
  sort infer_rhrmo dsplmo
  egen indfind = mean(cntfind/cntdspl), by(infer_rhrmo)
  if `dur'==12  replace indfind = . if int(infer_rhrmo/12 + 1960)<=1986
  if `dur'==48  replace indfind = . if int(infer_rhrmo/12 + 1960)<=1989
  label var indfind "Sh: Findings (displaced upto `dur' mo. ago)"
  sort infer_rhrmo dsplmo
  save `findrate'
  keep dsplmo indnorloc
  qui duplicates drop
  gen int ano = int(dsplmo/12 + 1960)
  gen month = dsplmo - (ano-1960)*12 + 1
  drop dsplmo
  rename indnorloc infer_indnorloc
  label var infer_indnorloc "Tenure-adj. Sh: Failed reall. (`dur' mo.)"
  order ano month infer_indnorloc
  label var ano "Calendar year"
  label var month "Calendar month"
  compress
  sort ano month
  save `infnoryr`dur''
  use `findrate'
  keep infer_rhrmo indfind
  qui duplicates drop
  gen int ano = int(infer_rhrmo/12 + 1960)
  gen month = infer_rhrmo - (ano-1960)*12 + 1
  drop infer_rhrmo
  rename indfind infer_indfind
  order ano month infer_indfind
  label var ano "Calendar year"
  label var month "Calendar month"
  compress
  sort ano month
  save "brazrloc/simul/v4/find-yr`dur'", replace

* employment statistics
restore, preserve
forvalues year = 1986/2001 {
  forvalues mo = 1/12 {
    * sector-year files
    tempfile secyr`dur'`year'm`mo'
    restore, preserve
    keep if ano==`year' & (mes_adm <= `mo' & mes_deslig >= `mo')  // observations of employment in `mo' and `year'
    qui duplicates tag wid, gen(duplobs)
    collapse (count) empl=wid (sum) duplobs (mean) inddspl indhire, by(cnaemix ano)
    gen byte month = `mo'
    label var month "Calendar month"
    order ano month cnaemix
    sort ano month cnaemix
    save `secyr`dur'`year'm`mo''
    * annual files
    tempfile yr`dur'`year'm`mo'
    restore, preserve
    keep if ano==`year' & (mes_adm <= `mo' & mes_deslig >= `mo')  // observations of employment in `mo' and `year'
    qui duplicates tag wid, gen(duplobs)
    collapse (count) empl=wid (sum) duplobs (mean) inddspl indhire, by(ano)
    gen byte month = `mo'
    label var month "Calendar month"
    order ano month
    sort ano month
    save `yr`dur'`year'm`mo''
    }
  }
restore

* assign indicator to workers not reemployed within 12 or 48
drop if inddspl==0
gen byte indnorloc = (mo2rehir > `dur' | mo2rehir==.)
keep ano indnorloc inddspl indhire indfemal indyoung indskloc indprim indhigh indcoll indany indnotprim mes_desl rem_media subs_ibge clas_cnae_95 cnaemix norloc_*
label var indnorloc "Indic.: No reall. in `dur' months"
sort ano mes ind*

* separation and accession rates by month and year
* table by month and year
preserve
collapse (mean) indnorloc norloc_inddspl norloc_indhire, by(ano mes_desl cnaemix) fast
rename mes_desl month
if `dur'==12  replace indnorloc=. if ano>=2001
if `dur'==48  replace indnorloc=. if ano>=1998
forvalues year = 1986/2001 {
  forvalues mo = 1/12 {
    sort ano month cnaemix
    merge ano month cnaemix using `secyr`dur'`year'm`mo'', update
    drop _m
    }
  }
label var month "Calendar month"
label var indnorloc "Sh: Failed reallocations"
label var norloc_inddspl "Sh: Separations in sep. mo."
label var norloc_indhire "Sh: Accessions same mo."
label var inddspl "Sh: Separations in cal. mo."
label var indhire "Sh: Accessions in cal. mo."
label var empl "Employment"
label var duplobs "Same-month reaccessions"
sort ano month cnaemix
merge ano month cnaemix using `infnorsecyr`dur''
drop _m
sort ano month cnaemix
compress
save "brazrloc/simul/v4/norlc-secyr`dur'", replace
restore, preserve
collapse (mean) indnorloc norloc_inddspl norloc_indhire, by(ano mes_desl) fast
rename mes_desl month
if `dur'==12  replace indnorloc=. if ano>=2001
if `dur'==48  replace indnorloc=. if ano>=1998
forvalues year = 1986/2001 {
  forvalues mo = 1/12 {
    sort ano month
    merge ano month using `yr`dur'`year'm`mo'', update
    drop _m
    }
  }
label var month "Calendar month"
label var indnorloc "Sh: Failed reallocations"
label var norloc_inddspl "Sh: Separations in sep. mo."
label var norloc_indhire "Sh: Accessions same mo."
label var inddspl "Sh: Separations in cal. mo."
label var indhire "Sh: Accessions in cal. mo."
label var empl "Employment"
label var duplobs "Same-month reaccessions"
sort ano month
merge ano month using `infnoryr`dur''
drop _m
sort ano month
compress
save "brazrloc/simul/v4/norlc-yr`dur'", replace
restore


* DURATIONS OF SUCCESSFUL REALLOCATIONS  AND MONTHLY SEPARATION AND ACCESSION RATES

use wid ano mes_adm mes_deslig identificad caus_desl_tc tipo_adm fx_etaria sexo occagg grau_instr rem_media subs_ibge clas_cnae_95 temp_empr using "brazrloc/data/wid-draw-workers-natl", clear
gen byte indfemal = (sexo==2) // female workers
label var indfemal "Indic.: Female worker"
drop sexo
qui gen byte indany   = 1
label var indany   "Indic.: Full sample"
qui gen byte indskloc = (occagg < 4)
label var indskloc "Indic.: White collar"

* update sector information with CNAE in 1994-2001 (563 industries), keep subsibge information for 1986-1993 (26 sectors)
gen long cnaemix = clas_cnae_95 // CNAE sector information in 1994-2001
replace cnaemix = subs_ibge if ano<=1993  // keep subsibge information for 1986-1993
label var cnaemix "Subsibge 1986-93, CNAE 94-2001"

* potential experience
qui gen workrage = 12 if fx_etaria==1
qui replace workrage =   16 if fx_etaria==2
qui replace workrage =   21 if fx_etaria==3
qui replace workrage =   27 if fx_etaria==4
qui replace workrage = 34.5 if fx_etaria==5
qui replace workrage = 44.5 if fx_etaria==6
qui replace workrage =   57 if fx_etaria==7
qui replace workrage =   .  if fx_etaria==8
label var workrage "Mid-point age in age group"
qui gen potexper     = workrage -  6 if grau_instr==1
qui replace potexper = workrage -  7 if grau_instr==2
qui replace potexper = workrage - 10 if grau_instr==3
qui replace potexper = workrage - 11 if grau_instr==4
qui replace potexper = workrage - 14 if grau_instr==5
qui replace potexper = workrage - 15 if grau_instr==6
qui replace potexper = workrage - 18 if grau_instr==7
qui replace potexper = workrage - 19 if grau_instr==8
qui replace potexper = workrage - 22 if grau_instr==9
qui label var potexper "Potential labor force experience"
qui gen byte indyoung = (potexper < 10)
label var indyoung "Indic.: 10 yrs or less exprienc."
drop workrage fx_etaria potexper

* education indicators
qui gen byte indprim = (grau_instr==1 | grau_instr==2 | grau_instr==3 | grau_instr==4 | grau_instr==5)
label var indprim "Primary or Middle School Educ."
qui gen byte indhigh = (grau_instr==6 | grau_instr==7)
label var indhigh "High School Education"
qui gen byte indcoll = (grau_instr==8 | grau_instr==9)
label var indcoll "College Education"
qui gen byte indnotprim = 1 - indprim
label var indnotprim "High School or College Educ."
drop grau_instr

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.
sort wid ano mes_adm mes_deslig identificad

* identify accession (excluding transfer)
gen byte indhire = (mes_adm > 0 & tipo_adm~=0 & tipo_adm~=3 & tipo_adm~=4)
label var indhire "Indic.: Accession"
egen mo2rhr_indhire = mean(indhire), by(ano mes_desl cnaemix)

* identify displacement and month of first rehiring
gen byte inddspl = (mes_deslig < 13 & caus_desl~=0 & caus_desl~=6 & caus_desl~=7 & caus_desl~=8)
by wid: gen str7 morehir = string(mes_adm[_n+1]) + "/" + string(ano[_n+1]) if inddspl==1
label var inddspl "Indic.: Displacement"
label var morehir "Month of first rehiring"
egen mo2rhr_inddspl = mean(inddspl), by(ano mes_desl cnaemix)

* discard rehirings if plant missing in year before rehiring
sort identificad ano
merge identificad ano using "brazrloc/data/rais-cnpj-list-natl"
tab _m
keep if _m==3
keep wid ano mes_adm mes_deslig identificad inddspl indhire morehir indabsyr1 caus_desl_tc indfemal indyoung indskloc indprim indhigh indcoll indnotprim indany rem_media subs_ibge clas_cnae_95 cnaemix mo2rhr_* temp_empr
sort wid ano mes_adm mes_deslig identificad
by wid: gen inddisc = indabsyr1[_n+1]
label var inddisc "Plant missing year bef. realloc."

* calculate months from displacement to first rehiring, if within 36 or 48 months
gen mo2rehir = (int(real(substr(morehir,-4,4))) - ano)*12 + (int(real(substr(morehir,1,index(morehir,"/")-1))) - mes_desl)
replace mo2rehir = 0 if int(real(substr(morehir,-4,4)))==ano & int(real(substr(morehir,1,index(morehir,"/")-1)))<mes_desl
replace mo2rehir = . if mo2rehir>`dur'
label var mo2rehir "Months to re-employment"

* employment statistics
preserve
forvalues year = 1986/2001 {
  forvalues mo = 1/12 {
    * sector-year files
    tempfile secyr`dur'`year'm`mo'
    restore, preserve
    keep if ano==`year' & (mes_adm <= `mo' & mes_deslig >= `mo')  // observations of employment in `mo' and `year'
    qui duplicates tag wid, gen(duplobs)
    collapse (count) empl=wid (sum) duplobs (mean) inddspl indhire, by(cnaemix ano)
    gen byte month = `mo'
    label var month "Calendar month"
    order ano month cnaemix
    sort ano month cnaemix
    save `secyr`dur'`year'm`mo''
    * annual files
    tempfile yr`dur'`year'm`mo'
    restore, preserve
    keep if ano==`year' & (mes_adm <= `mo' & mes_deslig >= `mo')  // observations of employment in `mo' and `year'
    qui duplicates tag wid, gen(duplobs)
    collapse (count) empl=wid (sum) duplobs (mean) inddspl indhire, by(ano)
    gen byte month = `mo'
    label var month "Calendar month"
    order ano month
    sort ano month
    save `yr`dur'`year'm`mo''
    }
  }
restore

* table by month and year
preserve
collapse (mean) mo2rehir mo2rhr_inddspl mo2rhr_indhire, by(ano mes_desl cnaemix) fast
rename mes_desl month
if `dur'==12  replace mo2rehir=. if ano>=2001
if `dur'==48  replace mo2rehir=. if ano>=1998
forvalues year = 1986/2001 {
  forvalues mo = 1/12 {
    sort ano month cnaemix
    merge ano month cnaemix using `secyr`dur'`year'm`mo'', update
    drop _m
    }
  }
label var month "Calendar month"
label var mo2rehir "Mean: Reallocation durations"
label var mo2rhr_inddspl "Sh: Separations in sep. mo."
label var mo2rhr_indhire "Sh: Accessions same mo."
label var inddspl "Sh: Separations in cal. mo."
label var indhire "Sh: Accessions in cal. mo."
label var empl "Employment"
label var duplobs "Same-month reaccessions"
sort ano month cnaemix
merge ano month cnaemix using `infrhrsecyr`dur''
drop _m
sort ano month cnaemix
compress
save "brazrloc/simul/v4/morhr-secyr`dur'", replace
restore, preserve
collapse (mean) mo2rehir mo2rhr_inddspl mo2rhr_indhire, by(ano mes_desl) fast
rename mes_desl month
if `dur'==12  replace mo2rehir=. if ano>=2001
if `dur'==48  replace mo2rehir=. if ano>=1998
forvalues year = 1986/2001 {
  forvalues mo = 1/12 {
    sort ano month
    merge ano month using `yr`dur'`year'm`mo'', update
    drop _m
    }
  }
label var month "Calendar month"
label var mo2rehir "Mean: Reallocation durations"
label var mo2rhr_inddspl "Sh: Separations in sep. mo."
label var mo2rhr_indhire "Sh: Accessions same mo."
label var inddspl "Sh: Separations in cal. mo."
label var indhire "Sh: Accessions in cal. mo."
label var empl "Employment"
label var duplobs "Same-month reaccessions"
sort ano month
merge ano month using `infrhryr`dur''
drop _m
sort ano month
compress
save "brazrloc/simul/v4/morhr-yr`dur'", replace
restore

}

log close
cd "$root"
